/* automatically generated from ./data/data.bin */
#ifdef __SUNPRO_C
#pragma align 4 (data_bin)
#endif
#ifdef __GNUC__
const char data_bin[] __attribute__ ((__aligned__ (4))) =
#else
const char data_bin[] =
#endif
{
  "L\377)\003\335\253\247\327\357\216\n\207\370N\036\247\024\233p\r\300\215"
  "\232\037hZ\036R\254l/V\375f\362\001o\271+\253\256\t_D\226.4\256\247\332"
  "\"\272\010\035""2A\014\257_/\013\022]\353\021\363fC\366\037\263\227\357"
  "\244\210\253\243K\241\375\243\'\256\355\344P\356&\320\204\312TWE\226\326"
  "\351*\355\'\321-Ju\031\027\234\240:\'a\261.\364\224\300\272O\364\333\035"
  "Sv\177{\002""5\206\225k\030\243-.RTU\340\373""8\254\327Xt\327\262\371\314"
  "\220\262.\r\307\262\377\014\346:\335\023""794\271\355\014\030\373\351\005"
  "\270\371\254V\006\251\372\316\336,\266\366&Mf\275\027(p\\\371\253@\263\307"
  "\374z\222\250J\'\363I\227\006Z\273!\265""7\363\326\340\000(af\272\232,j"
  "\275j~z\307\236\231\032\375\303\025""1_\334""5\021{\317%\233-!\344\334\303"
  "\365\231\241\335\023\307\374\274\313\200\344\347\261*qLL\364\202\241\256"
  "\017\253YX\007\352\201E/\340q\033\222\017|\366]xOG\250\370[[\350[\257""2"
  "T\237\343""4\206\362\373\237\351\354\200\216_;2sh\013\254\016|t\031\310"
  "@\221\221\024\022\353\333d\311\377\254\317Z\204\320\020\033\343\355""7\223"
  "\377*\257\223\351\332F\026\204\334\376\036\352\222""8\325\026\301\355\316"
  "\250?\311]\204r*\207D\027_ \251\031a\376\311\212f\r\340\034\033V\n\241\243"
  "\270\002n\231\330\342\275/g\265\025@\220 \261\334\257\261\005h\306""0m\027"
  "\004E\353\373I*\355\307\r\226\374z9\272\006]\234={\332\315\035\322\375\353"
  "\216ldW=\301\346\331\330\261""2\324W\221\333\206""5\332\341R\014\345w\360"
  "\351\365\223\316\337/\323\316\311a\255\264\022\275\300\340`c\347W\206p7"
  "\020z[\334Q*\224\315\003\200""1\340g>\214\330U\t\263\200\240c9\255\267\370"
  "<e\347Kh2@\201\237m\340\313\000\026e\277""3U\224\223\211_NF\316""3\374\202"
  "T;\237{\222~\250\232""1\224_`6\014""7\275\t/\333\212\226S8\242EU\312T\020"
  "\035!\371\353""1\304\014\033 \205\220\256\333\270p\250\'\226!\262C\362\307"
  "K\r\274\240\366[N\325s\350\261\260\360\204\364R\037\026\371\'\022s\177O"
  "(\004@\\\035\200\303\264\376\205\342\207\330XKF\355\021\242x\253\246\261"
  "\306\264N\306J\200\356\020.\217\236\340\226.@\254\263\376""56jI\342\230"
  "]RzX\246\210\217\233s\302\205\327].\211[{\252\251\267B\364*\252\325\"_\315"
  "\253,\377\364\244\230Os|E\335""0\335\337#\300bj\214\347\373\374kAG\005W"
  "\276\274\304\nHJ$Ft\362\265\274I\217\254\002\374\303\021\242\223\001g<\311"
  "h\257\265\177ZE\370\352\030\366(}\021\232M=\n\273\357?\257i\223""1\216:"
  "\004\353H3J0\207\237\234D\225\271\352\360\215\304~\330\246\346""4\344@\311"
  "n\206\373\032\313\033\\\306\332\022\335)\215\036\325\344\027?]\303\211\243"
  "\377\301\221LHQ~\301\033\001`\347\356\311hZ\030\036\275\260\017t\225v\253"
  "\346\325\022\335\371P\220\027\304\246q\307\361\333z\357\000\262\032\275"
  "Q+\202M\347\032O^\272n\264\264DN\311\275m\323\000\014\250\273\210\270+["
  "0\034\357\313{\365\234\261}\307!\363\263\225\256\325\336:\264\361\271<K"
  "\037\246\010\205L\304V\r\317mv4\340\005\346\364!8\r\020S\r\227\020D\320"
  "\315\031\006\327\373\211\247;q)O\321\'\000\343\006Da\'\223\236""6\035s\262"
  "@\004\374[\333zS\231\356\360\300s\210k\037c\235B]\020\310\'\341\256,\240"
  ">3sx\212\347\206\335""1\302\250A\351\262\205\026\tC\312\237\371\223xk\'"
  "U\261d\034\226J4\302\006w\247\310d\"8eqqX\351\235\252.\311\363\272y\321"
  "\360\260\201\374\021w\210$ /\230\260\257\024\030\361Sa\250\313\330\256\366"
  "\023/lR^\216""1\022\371""0\321X\027\316\337\350\214=\'\270\247J\254In!\272"
  "\273\374\354\241\343""1WS\315\025 \226F\260\\\325\366\311h\344\326\321;"
  "pk\026\272\326\003\332C\353qx^8@\203_\307\214t%.\367\206\330\364;+\213\360"
  """22\207\301\347\276""2\014h4\310l\272!\200\321w\211\032\351\342\376\373"
  "\306^k\212\031\210b\036I5I\302\305CB;\007""9\246Y\342\263\362E\034\000F"
  "\260\250\247\211\254\217>\317&}h\214\345\034\025n\317\342JK\357""6\026""7"
  "R[\236\341\220\204}Pq\013\240B\315\230C\317\263C\357FQV\013\346qf\016j#"
  "\031|\216B.}\247\035\355\272\341\241X\354\'6\240e\274\224@\340\370\256\254"
  "\243-\257\243V8\262\342u4`\223\236q\005\276\026\361""5o\034\"n\303H\327"
  "dG\315\330\345<\255.>\350L\257\355\020\362\355""2\271\343\034\223\007\361"
  "\317\261;\251\301\242""3\236\301S\265\330\321""4\245\210\307\005\353}\""
  "\326\267R\344\"\244A\271 \305\262\257\330""9,\035\242\301\r\254\335k5D|"
  "\346{\370y\300m\354O\017""0.\266\337P\305m\177\200\016#\212\247\257q\364"
  "\263\345\310\274d\333\254\372\373\275d]/e\227\311.\224\375c\344=\331\\r"
  "7\200""4\003|\263\227wK\301\327Nd\341\351\245\003\362|\\\263\261n\336[B"
  "\002\211\320\005x \033\351Q+\310\270\234\372\365O\315""30?\020""7a\234\277"
  "\253\032\016s2\301\334A{U\277\263""8\373\010\222p\211)T\252""7^\005S\364"
  "\215iZ*J\204<\033\370^xBi\030$\237G\017\016g\202m\025F\234\277\"\235Z\254"
  "s\252\221""0q4\245""3\331\274;\246\034Z\216Yx\016\314D,\276\336\227\361"
  "Q(l\207p\211V\311BR\002v\010\022\341\004o\343mu\002d;\242\023X\233""8iP"
  "|\343(\026(Q\354\323Ir\303o\021\364P\202\027\211|\317\250\373\340>\356\226"
  "EB3\354\245\322\325\265\205\025=\230D\032^vL\202\360\223,\017""8f\276f\310"
  "V\315\266\033#\227\272\304""1\245\277F\001\251(\003\\\\\014\n\006u\357\251"
  "\364\302Hm\363\260n\030\340\300\201""1_\252\343d\375T\300\366rsL\223\260"
  "\220\362\251s2\355""7H\257\320\005{\320Hx\210R\305\300\275C\344d\220\345"
  "\020\305\201x\267\324\305\234\341\300\365\353\330\276g\312\n$\272\340\356"
  "\366\376#:\017\262\204\255""5\352\334\364p\335\211\213""7\334\233c\302\262"
  "\034\037,\307\036\337""0.9\366p\351\031E\020\377\347""16\275""4\033\334"
  "\030\324\326\345\267(\255\206\364d\273\317\243~\007\216g\342\245g\375A\023"
  "\302|w.\034""2\335\301\263""3G^\366""0HV\210\332\227""7\375\023A\350\325"
  "\354p\324\"L\314""4Wt\217\257c\342Qi\216\221\324\232\222H\023\343\302w\255"
  """3-n\343\004\230L\263f\227D{/\210`\241\201\363\220\273\353\217\223\243"
  "^\316\223y\027\350\203""1F5\325\377\234\302<\370\271U\273 \303\'\352\362"
  "\022\263\227\240\251\273\332\317\353\341\344y\014""6\222\204\034T)\343\037"
  "\224\313\274R\253s\311\212\331\303*2\301_<w\356\240\220\224(7s\212@\243"
  "\314\273\n\324q+\376TBoj\276Xc/\344@\r\217\341q\301\244\374\324\235\345"
  "\361)p\276\375|\321/?\204\235\223\316""5s;\342/m&\252\010\324W\273\007i"
  "\263\326\361\000I&\356""4Z\360R[2%\223\324""5\333\375[\247Oi\373\023\014"
  "s\302\013yK\204\016\251\020Z{\326\201\022\210\305\357\026%\tl&\311""7\344"
  "n\241\036!L0h\255\017\017\353($$\302\213\030\351\356\242\263\202\350\324"
  "D&&\300s\217n\013\014~(\302\252~\275V\223\242\037""4\027r\321FWV-\256\310"
  "x\t)\202Ew\004\374Zo\223\242\210\007\"\217\352\240n\254~O\371\347\323B\203"
  "\261>\216tR\252\315\213\n\366\022\013\377\237\257\224\213\254\252\037-\261"
  "\232\342ji\260""9y\035\374\277SV\346%\253\236\304\020/B\316\250\224W\231"
  "\343\025v(\322\347w\226""8C \020\303\315\223\353\244B\022Sn8A\240u\354\203"
  "\304\210\274A\016Z\304I\265\000,J=\021\350h\026\365Bm\343\321\377K.~ \004"
  "\267\300\223[\220S+dX\322\345P\267\204\312\230\220$-^\207\230\024\217\273"
  "\251\207\352b\222/\317\341\025vgtpH(~\354\337\352`\247siDf\333\201\366\344"
  "\237""5\217\274F\345\255\033Zu8\300=\311|\345\340\371\017+\353\357Sy\270"
  """4M\366\333+9\332\353\333\216W\016Q\030\243)\271A\010\025\217n\323\306"
  """9_#\003\311\272\265dA\272\236\315\020\375\224<\366o\320\260 \246\331\375"
  "\307t\243V\256\235o8\177\300H\326\310N\005r3J\215\303\357\005\267""0\271"
  "\365\026\347\200\033?\024\235n\032\360h{1\333\022\337\362(\000s\215\016"
  "D%\222\030""4\264)C&\242\335\324Kj+\312R\207\231\033t\206<_\344W}N\376k"
  "j\247\324=E\331\235\327\037\270\311\351\006\035\340k\250\323\000>\241$g"
  "E\001\302\357\303>\342\312\253""9\340Z\255\226c1,\315K\264\305Muf\241\274"
  "k\277\353%j\342C\'\304E\tP\027\323""6\265(\243\236\220-%\364\274\026\345"
  "\344\224\256\335\'y?\205q?\211\370Hc\234\366\034yjT\016\304z\261<\230\224"
  "\357\002""7\203\334Zv\003\336\240~cl\034z^`g\272\026J\266Ik\024Y%\263\366"
  "\036g\334\272\020W\327\300,K\253\341\367\031\365 qz\202;\006^\312\315\250"
  "FYL\021Df\305\276\177""8\315\317\213\227\373\234\277""14~BH\"\344Y\252\243"
  "\246<\215R\241\265\335`Yu\324\271\341\300\305\255U\236C*V\356\260e\347\354"
  "\243v\352e\"\\ +}\321""6\342\265\013;W\247\210\036\362R+t`\025\360\222O"
  "\235\250\n\204\014\345\357\017\307\302*rR\222\030\340H\034\372\t\036\302"
  "\201\023\372\324\377YTS\252\030""6\266f&rG{\316\315\202X\355\366\233\360"
  "g\354+\270\310\352B\272\331\371\002wY\235\270\255\320|U^C\203\273\215\215"
  "w\337\265\316A\336\017_T\372\"\234\217\274\000\335r\327y}\037\367\326\326"
  "\247\025""3\324\233\202c<\260\336\340\017\360VJ\035\245\324\014U\013M\347"
  "\271v\005\324g\377pN\252,\340q\212\023\260\030\361\262\326\024\301\363\002"
  "\016QJ\255\034\315\263}f2\"/\234\341\213,\217\201\007\270)\301\270\252\316"
  "z(e\215=\204%\303D\365\332|\316\241\347u0\006\361\254\206\032\203\210\023"
  "~\\\232\241""5\223\345\200C\272\355@\016\213\207\334)6_\236\007/\205\005"
  "\"\244\006\330\\\354Z\224\306\230\201\234\234\250\241\264\001Q0\201\254"
  "\226X\035-u\223}u\t\342\350\r\266M\252\224\026(\225\'\263\237r\007B\275"
  "\227Bb=ci\014\275\300L)\254\'\305.q\034\365\350\241\017A\256\372\241\365"
  "E0K\256 gB\"\335\334dB+d\236o)\265f\026P\307\021\335\327\030\216\311\222"
  "c[\323\217\342\202_\305\273p\246\315\005""1\033O\247\372X\235\274\304\304"
  "\t!\021\367\371\366O\344\000\241\327\007\220.I\010R\376\325\304e\r\364""1"
  "\333\031\035\265\310r\234\234\261JG\334]\260\214\277\315&\007\366\344a\340"
  "\372\"Zi~\211DT\323\246\354\177\327J\032\'3QC)\230\214\354\252g\254\260"
  "G1\305\201^ClVRe\240\262\265M\257\337\210\005\360\200\355V\267\366\274\270"
  "n\274""2\361;\t\372\241\316\326\027T\271!\000A\241\240\177\003>f\352\256"
  "\351Y\037V}\246\241j\265\335&\214\355\351\034S\373\255\312X\032""3u\270"
  "\232\366\361I.B\376\023|GC\354\323@\337\'\355\200\311\024\216C-\226\242"
  "&\035\307\313\033g\357d\005\202B\216\241Z\250zw\034X\346\013\276\303\354"
  "\005W\363c\234\033\227\376i\324\225Ro\375\343\266\010""5\276\252\371\266"
  "\324vH,\347H\271L\rmlm\207~|\253\247\360j\217\361\216\357\207\362\035\252"
  "\345\273\000""7\206^N\227\340h\363h?\376\373\214~]\362&\371""4\375\036\275"
  "\336f(=\361\305\227.\274v\222B\255""5Z^\271\327\245$\243\242\325\271\227"
  "\231u\277\233f\016\r\242\255""7AWuf2\253\333\005\317\322x\006)q\236\013"
  "T\024U%)H\217U?\377U\262\271\275\346\245""4I\364\271\327=\347V-\334+@9\270"
  "\207\207\214\"\247.\002\332\336/,\351u;\327\371""8\273l\331[wc\201\236}"
  "\333\343\361\021n\212\317\323%G\207\240:\243\033\363\317\273]Td-\306\223"
  "u\304\261\324\341\333E\353\021\361KiE\247\306\341v\004[9\001\306\n\357\025"
  "(N\242\036\316\346IG\022\213>\375nf\001S\253\367\310\371\261\016o\025\254"
  "\220\213\301\220\226\027\201\r\333\205\232\023\337\027\270\366\265\336\374"
  "\352\240\333*\321_qD\273\267\265\373S\225j\214\246\035+\371\036k\341\365"
  "\214V\343E\207)\236K\341\023\255\333\360""3\314\266\034\242\240""6\230""1"
  "\336""3\342T\355c\372\323\006\204%b\223\222\027\020M\370\032\314h\001\022"
  "x\262-m\016\276\022\355\272\201\201\214\"\267%\355\330>\346\377\030c\332"
  "\364;\n\270c\205fB}Tz\224\210\303\302$/\211\247\003u(\213=\354\274\013\022"
  "\243\341Y\210\237<\332\322\"\215\234>c\027B\211C\276\265\305\372\004Q\302"
  "l\322\332P:\247""5\327\311f\334\205\031\347M\243rhWA\316\\\212\344gs\212"
  "\252\371\223\300\311\202sl\305_;\267\r\357a\r\036\276\271\275\216\034\320"
  "<\364Py\345\370IX\352\010!\r\226\020\020e\204\346\354\032\207G\375\010\217"
  "\201\276\240\326?\t\250\264\270j\263\272O\366\345VN>\227\371\202\353\264"
  """5\242""8\352\375\344\377/\352\342,\314S\324\026\372yu\272}\214q\326\250"
  "G\245>1\255Q\361\210\323""3#\275l,\277Y$x\"\341M\325c\337\325\353E!\353"
  "\321\313\013\237N\212V\222\347\202\342""0\205\355\372\230\007]\002\371\\"
  "K\002o\326\215hn\256\370\201\026\227\240\210v\335\245\006\226v\325\200\252"
  "\022\330\364\266\217\313\265q\337\302_\007\010<\220\t\223@\365\244\201{"
  "\207\322\330W-\326\355+/]\340\226\t\306""0\007""9\340!\307\005\235H\034"
  """7\353D\177r\333\331\266\312\202&~\366N\351*A]d\364\n\004<\344\347\030"
  "Q\331?\330G\"\004\220\010P\250u\234\205\336w\275\022\253\026\300\202\227"
  "\376U\'s\341\177\316\313F@\374M\256\013\310\342\372\354\343\220\252\363"
  "\357:]\253\031u\262.\333]\367\376\344\031\312\354\370\363#\204g\232\234"
  "\302\016\302\213\007,\205U\320E\260\rD\036\245\211\017q\212\221\r\264=\004"
  "V\016""1\350\014\022\232\261h9\000\245\336\252\350YM\003\177\256\337\343"
  "\032V~\202\226\275x\242\n2\034h\363\'s >:\215TK\213\317\017!V\013\207\200"
  ":\272\020\013\323\265\037\311j\004\022,\014\033#a\351\315\237P\022\217\353"
  ";\204\205)\215\245\236\226\t7\364\215\320\310\337yHC\337\343\360\013:\035"
  """0\234\263""5Q\326\342I,\227R5SH\264{nh\327"
};

const unsigned data_bin_length = 4096u;

/* automatically generated from ./data/data.txt */
#ifdef __SUNPRO_C
#pragma align 4 (data_txt)
#endif
#ifdef __GNUC__
const char data_txt[] __attribute__ ((__aligned__ (4))) =
#else
const char data_txt[] =
#endif
{
  "\t\t  GNU LIBRARY GENERAL PUBLIC LICENSE\n\t\t       Version 2, June 19"
  "91\n\n Copyright (C) 1991 Free Software Foundation, Inc.\n    \t\t    5"
  "9 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n Everyone is pe"
  "rmitted to copy and distribute verbatim copies\n of this license docume"
  "nt, but changing it is not allowed.\n\n[This is the first released vers"
  "ion of the library GPL.  It is\n numbered 2 because it goes with versio"
  "n 2 of the ordinary GPL.]\n\n\t\t\t    Preamble\n\n  The licenses for m"
  "ost software are designed to take away your\nfreedom to share and chang"
  "e it.  By contrast, the GNU General Public\nLicenses are intended to gu"
  "arantee your freedom to share and change\nfree software--to make sure t"
  "he software is free for all its users.\n\n  This license, the Library G"
  "eneral Public License, applies to some\nspecially designated Free Softw"
  "are Foundation software, and to any\nother libraries whose authors deci"
  "de to use it.  You can use it for\nyour libraries, too.\n\n  When we sp"
  "eak of free software, we are referring to freedom, not\nprice.  Our Gen"
  "eral Public Licenses are designed to make sure that you\nhave the freed"
  "om to distribute copies of free software (and charge for\nthis service "
  "if you wish), that you receive source code or can get it\nif you want i"
  "t, that you can change the software or use pieces of it\nin new free pr"
  "ograms; and that you know you can do these things.\n\n  To protect your"
  " rights, we need to make restrictions that forbid\nanyone to deny you t"
  "hese rights or to ask you to surrender the rights.\nThese restrictions "
  "translate to certain responsibilities for you if\nyou distribute copies"
  " of the library, or if you modify it.\n\n  For example, if you distribu"
  "te copies of the library, whether gratis\nor for a fee, you must give t"
  "he recipients all the rights that we gave\nyou.  You must make sure tha"
  "t they, too, receive or can get the source\ncode.  If you link a progra"
  "m with the library, you must provide\ncomplete object files to the reci"
  "pients so that they can relink them\nwith the library, after making cha"
  "nges to the library and recompiling\nit.  And you must show them these "
  "terms so they know their rights.\n\n  Our method of protecting your rig"
  "hts has two steps: (1) copyright\nthe library, and (2) offer you this l"
  "icense which gives you legal\npermission to copy, distribute and/or mod"
  "ify the library.\n\n  Also, for each distributor\'s protection, we want"
  " to make certain\nthat everyone understands that there is no warranty f"
  "or this free\nlibrary.  If the library is modified by someone else and "
  "passed on, we\nwant its recipients to know that what they have is not t"
  "he original\nversion, so that any problems introduced by others will no"
  "t reflect on\nthe original authors\' reputations.\n\014\n  Finally, any"
  " free program is threatened constantly by software\npatents.  We wish t"
  "o avoid the danger that companies distributing free\nsoftware will indi"
  "vidually obtain patent licenses, thus in effect\ntransforming the progr"
  "am into proprietary software.  To prevent this,\nwe have made it clear "
  "that any patent must be licensed for everyone\'s\nfree use or not licen"
  "sed at all.\n\n  Most GNU software, including some libraries, is covere"
  "d by the ordinary\nGNU General Public License, which was designed for u"
  "tility programs.  This\nlicense, the GNU Library General Public License"
  ", applies to certain\ndesignated libraries.  This license is quite diff"
  "erent from the ordinary\none; be sure to read it in full, and don\'t as"
  "sume that anything in it is\nthe same as in the ordinary license.\n\n  "
  "The reason we have a separate public license for some libraries is that"
  "\nthey blur the distinction we usually make between modifying or adding"
  " to a\nprogram and simply using it.  Linking a program with a library, "
  "without\nchanging the library, is in some sense simply using the librar"
  "y, and is\nanalogous to running a utility program or application progra"
  "m.  However, in\na textual and legal sense, the linked executable is a "
  "combined work, a\nderivative of the original library, and the ordinary "
  "General Public License\ntreats it as such.\n\n  Because of this blurred"
  " distinction, using the ordinary General\nPublic License for libraries "
  "did not effectively promote software\nsharing, because most developers "
  "did not use the libraries.  We\nconcluded that weaker conditions might "
  "promote sharing better.\n\n  However, unrestricted linking of non-free "
  "programs would deprive the\nusers of those programs of all benefit from"
  " the free status of the\nlibraries themselves.  This Library General Pu"
  "blic License is intended to\npermit developers of non-free programs to "
  "use free libraries, while\npreserving your freedom as a user of such pr"
  "ograms to change the free\nlibraries that are incorporated in them.  (W"
  "e have not seen how to achieve\nthis as regards changes in header files"
  ", but we have achieved it as regards\nchanges in the actual functions o"
  "f the Library.)  The hope is that this\nwill lead to faster development"
  " of free libraries.\n\n  The precise terms and conditions for copying, "
  "distribution and\nmodification follow.  Pay close attention to the diff"
  "erence between a\n\"work based on the library\" and a \"work that uses "
  "the library\".  The\nformer contains code derived from the library, whi"
  "le the latter only\nworks together with the library.\n\n  Note that it "
  "is possible for a library to be covered by the ordinary\nGeneral Public"
  " License rather than by this special one.\n\014\n\t\t  GNU LIBRARY GENE"
  "RAL PUBLIC LICENSE\n   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION A"
  "ND MODIFICATION\n\n  0. This License Agreement applies to any software "
  "library which\ncontains a notice placed by the copyright holder or othe"
  "r authorized\nparty saying it may be distributed under the terms of thi"
  "s Library\nGeneral Public License (also called \"this License\").  Each"
  " licensee is\naddressed as \"you\".\n\n  A \"library\" means a collecti"
  "on of software functions and/or data\nprepared so as to be conveniently"
  " linked with application programs\n(which use some of those functions a"
  "nd data) to form executables.\n\n  The \"Library\", below, refers to an"
  "y such software library or work\nwhich has been distributed under these"
  " terms.  A \"work based on the\nLibrary\" means either the Library or a"
  "ny derivative work under\ncopyright law: that is to say, a work contain"
  "ing the Library or a\nportion of it, either verbatim or with modificati"
  "ons and/or translated\nstraightforwardly into another language.  (Herei"
  "nafter, translation is\nincluded without limitation in the term \"modif"
  "ication\".)\n\n  \"Source code\" for a work means the preferred form of"
  " the work for\nmaking modifications to it.  For a library, complete sou"
  "rce code means\nall the source code for all modules it contains, plus a"
  "ny associated\ninterface definition files, plus the scripts used to con"
  "trol compilation\nand installation of the library.\n\n  Activities othe"
  "r than copying, distribution and modification are not\ncovered by this "
  "License; they are outside its scope.  The act of\nrunning a program usi"
  "ng the Library is not restricted, and output from\nsuch a program is co"
  "vered only if its contents constitute a work based\non the Library (ind"
  "ependent of the use of the Library in a tool for\nwriting it).  Whether"
  " that is true depends on what the Library does\nand what the program th"
  "at uses the Library does.\n  \n  1. You may copy and distribute verbati"
  "m copies of the Library\'s\ncomplete source code as you receive it, in "
  "any medium, provided that\nyou conspicuously and appropriately publish "
  "on each copy an\nappropriate copyright notice and disclaimer of warrant"
  "y; keep intact\nall the notices that refer to this License and to the a"
  "bsence of any\nwarranty; and distribute a copy of this License along wi"
  "th the\nLibrary.\n\n  You may charge a fee for the physical act of tran"
  "sferring a copy,\nand you may at your option offer warranty protection "
  "in exchange for a\nfee.\n\014\n  2. You may modify your copy or copies "
  "of the Library or any portion\nof it, thus forming a work based on the "
  "Library, and copy and\ndistribute such modifications or work under the "
  "terms of Section 1\nabove, provided that you also meet all of these con"
  "ditions:\n\n    a) The modified work must itself be a software library."
  "\n\n    b) You must cause the files modified to carry prominent notices"
  "\n    stating that you changed the files and the date of any change.\n\n"
  "    c) You must cause the whole of the work to be licensed at no\n    c"
  "harge to all third parties under the terms of this License.\n\n    d) I"
  "f a facility in the modified Library refers to a function or a\n    tab"
  "le of data to be supplied by an application program that uses\n    the "
  "facility, other than as an argument passed when the facility\n    is in"
  "voked, then you must make a good faith effort to ensure that,\n    in t"
  "he event an application does not supply such function or\n    table, th"
  "e facility still operates, and performs whatever part of\n    its purpo"
  "se remains meaningful.\n\n    (For example, a function in a library to "
  "compute square roots has\n    a purpose that is entirely well-defined i"
  "ndependent of the\n    application.  Therefore, Subsection 2d requires "
  "that any\n    application-supplied function or table used by this funct"
  "ion must\n    be optional: if the application does not supply it, the s"
  "quare\n    root function must still compute square roots.)\n\nThese req"
  "uirements apply to the modified work as a whole.  If\nidentifiable sect"
  "ions of that work are not derived from the Library,\nand can be reasona"
  "bly considered independent and separate works in\nthemselves, then this"
  " License, and its terms, do not apply to those\nsections when you distr"
  "ibute them as separate works.  But when you\ndistribute the same sectio"
  "ns as part of a whole which is a work based\non the Library, the distri"
  "bution of the whole must be on the terms of\nthis License, whose permis"
  "sions for other licensees extend to the\nentire whole, and thus to each"
  " and every part regardless of who wrote\nit.\n\nThus, it is not the int"
  "ent of this section to claim rights or contest\nyour rights to work wri"
  "tten entirely by you; rather, the intent is to\nexercise the right to c"
  "ontrol the distribution of derivative or\ncollective works based on the"
  " Library.\n\nIn addition, mere aggregation of another work not based on"
  " the Library\nwith the Library (or with a work based on the Library) on"
  " a volume of\na storage or distribution medium does not bring the other"
  " work under\nthe scope of this License.\n\n  3. You may opt to apply th"
  "e terms of the ordinary GNU General Public\nLicense instead of this Lic"
  "ense to a given copy of the Library.  To do\nthis, you must alter all t"
  "he notices that refer to this License, so\nthat they refer to the ordin"
  "ary GNU General Public License, version 2,\ninstead of to this License."
  "  (If a newer version than version 2 of the\nordinary GNU General Publi"
  "c License has appeared, then you can specify\nthat version instead if y"
  "ou wish.)  Do not make any other change in\nthese notices.\n\014\n  Onc"
  "e this change is made in a given copy, it is irreversible for\nthat cop"
  "y, so the ordinary GNU General Public License applies to all\nsubsequen"
  "t copies and derivative works made from that copy.\n\n  This option is "
  "useful when you wish to copy part of the code of\nthe Library into a pr"
  "ogram that is not a library.\n\n  4. You may copy and distribute the Li"
  "brary (or a portion or\nderivative of it, under Section 2) in object co"
  "de or executable form\nunder the terms of Sections 1 and 2 above provid"
  "ed that you accompany\nit with the complete corresponding machine-reada"
  "ble source code, which\nmust be distributed under the terms of Sections"
  " 1 and 2 above on a\nmedium customarily used for software interchange.\n"
  "\n  If distribution of object code is made by offering access to copy\n"
  "from a designated place, then offering equivalent access to copy the\ns"
  "ource code from the same place satisfies the requirement to\ndistribute"
  " the source code, even though third parties are not\ncompelled to copy "
  "the source along with the object code.\n\n  5. A program that contains "
  "no derivative of any portion of the\nLibrary, but is designed to work w"
  "ith the Library by being compiled or\nlinked with it, is called a \"wor"
  "k that uses the Library\".  Such a\nwork, in isolation, is not a deriva"
  "tive work of the Library, and\ntherefore falls outside the scope of thi"
  "s License.\n\n  However, linking a \"work that uses the Library\" with "
  "the Library\ncreates an executable that is a derivative of the Library "
  "(because it\ncontains portions of the Library), rather than a \"work th"
  "at uses the\nlibrary\".  The executable is therefore covered by this Li"
  "cense.\nSection 6 states terms for distribution of such executables.\n\n"
  "  When a \"work that uses the Library\" uses material from a header fil"
  "e\nthat is part of the Library, the object code for the work may be a\n"
  "derivative work of the Library even though the source code is not.\nWhe"
  "ther this is true is especially significant if the work can be\nlinked "
  "without the Library, or if the work is itself a library.  The\nthreshol"
  "d for this to be true is not precisely defined by law.\n\n  If such an "
  "object file uses only numerical parameters, data\nstructure layouts and"
  " accessors, and small macros and small inline\nfunctions (ten lines or "
  "less in length), then the use of the object\nfile is unrestricted, rega"
  "rdless of whether it is legally a derivative\nwork.  (Executables conta"
  "ining this object code plus portions of the\nLibrary will still fall un"
  "der Section 6.)\n\n  Otherwise, if the work is a derivative of the Libr"
  "ary, you may\ndistribute the object code for the work under the terms o"
  "f Section 6.\nAny executables containing that work also fall under Sect"
  "ion 6,\nwhether or not they are linked directly with the Library itself"
  ".\n\014\n  6. As an exception to the Sections above, you may also compi"
  "le or\nlink a \"work that uses the Library\" with the Library to produc"
  "e a\nwork containing portions of the Library, and distribute that work\n"
  "under terms of your choice, provided that the terms permit\nmodificatio"
  "n of the work for the customer\'s own use and reverse\nengineering for "
  "debugging such modifications.\n\n  You must give prominent notice with "
  "each copy of the work that the\nLibrary is used in it and that the Libr"
  "ary and its use are covered by\nthis License.  You must supply a copy o"
  "f this License.  If the work\nduring execution displays copyright notic"
  "es, you must include the\ncopyright notice for the Library among them, "
  "as well as a reference\ndirecting the user to the copy of this License."
  "  Also, you must do one\nof these things:\n\n    a) Accompany the work "
  "with the complete corresponding\n    machine-readable source code for t"
  "he Library including whatever\n    changes were used in the work (which"
  " must be distributed under\n    Sections 1 and 2 above); and, if the wo"
  "rk is an executable linked\n    with the Library, with the complete mac"
  "hine-readable \"work that\n    uses the Library\", as object code and/o"
  "r source code, so that the\n    user can modify the Library and then re"
  "link to produce a modified\n    executable containing the modified Libr"
  "ary.  (It is understood\n    that the user who changes the contents of "
  "definitions files in the\n    Library will not necessarily be able to r"
  "ecompile the application\n    to use the modified definitions.)\n\n    "
  "b) Accompany the work with a written offer, valid for at\n    least thr"
  "ee years, to give the same user the materials\n    specified in Subsect"
  "ion 6a, above, for a charge no more\n    than the cost of performing th"
  "is distribution.\n\n    c) If distribution of the work is made by offer"
  "ing access to copy\n    from a designated place, offer equivalent acces"
  "s to copy the above\n    specified materials from the same place.\n\n  "
  "  d) Verify that the user has already received a copy of these\n    mat"
  "erials or that you have already sent this user a copy.\n\n  For an exec"
  "utable, the required form of the \"work that uses the\nLibrary\" must i"
  "nclude any data and utility programs needed for\nreproducing the execut"
  "able from it.  However, as a special exception,\nthe source code distri"
  "buted need not include anything that is normally\ndistributed (in eithe"
  "r source or binary form) with the major\ncomponents (compiler, kernel, "
  "and so on) of the operating system on\nwhich the executable runs, unles"
  "s that component itself accompanies\nthe executable.\n\n  It may happen"
  " that this requirement contradicts the license\nrestrictions of other p"
  "roprietary libraries that do not normally\naccompany the operating syst"
  "em.  Such a contradiction means you cannot\nuse both them and the Libra"
  "ry together in an executable that you\ndistribute.\n\014\n  7. You may "
  "place library facilities that are a work based on the\nLibrary side-by-"
  "side in a single library together with other library\nfacilities not co"
  "vered by this License, and distribute such a combined\nlibrary, provide"
  "d that the separate distribution of the work based on\nthe Library and "
  "of the other library facilities is otherwise\npermitted, and provided t"
  "hat you do these two things:\n\n    a) Accompany the combined library w"
  "ith a copy of the same work\n    based on the Library, uncombined with "
  "any other library\n    facilities.  This must be distributed under the "
  "terms of the\n    Sections above.\n\n    b) Give prominent notice with "
  "the combined library of the fact\n    that part of it is a work based o"
  "n the Library, and explaining\n    where to find the accompanying uncom"
  "bined form of the same work.\n\n  8. You may not copy, modify, sublicen"
  "se, link with, or distribute\nthe Library except as expressly provided "
  "under this License.  Any\nattempt otherwise to copy, modify, sublicense"
  ", link with, or\ndistribute the Library is void, and will automatically"
  " terminate your\nrights under this License.  However, parties who have "
  "received copies,\nor rights, from you under this License will not have "
  "their licenses\nterminated so long as such parties remain in full compl"
  "iance.\n\n  9. You are not required to accept this License, since you h"
  "ave not\nsigned it.  However, nothing else grants you permission to mod"
  "ify or\ndistribute the Library or its derivative works.  These actions "
  "are\nprohibited by law if you do not accept this License.  Therefore, b"
  "y\nmodifying or distributing the Library (or any work based on the\nLib"
  "rary), you indicate your acceptance of this License to do so, and\nall "
  "its terms and conditions for copying, distributing or modifying\nthe Li"
  "brary or works based on it.\n\n  10. Each time you redistribute the Lib"
  "rary (or any work based on the\nLibrary), the recipient automatically r"
  "eceives a license from the\noriginal licensor to copy, distribute, link"
  " with or modify the Library\nsubject to these terms and conditions.  Yo"
  "u may not impose any further\nrestrictions on the recipients\' exercise"
  " of the rights granted herein.\nYou are not responsible for enforcing c"
  "ompliance by third parties to\nthis License.\n\014\n  11. If, as a cons"
  "equence of a court judgment or allegation of patent\ninfringement or fo"
  "r any other reason (not limited to patent issues),\nconditions are impo"
  "sed on you (whether by court order, agreement or\notherwise) that contr"
  "adict the conditions of this License, they do not\nexcuse you from the "
  "conditions of this License.  If you cannot\ndistribute so as to satisfy"
  " simultaneously your obligations under this\nLicense and any other pert"
  "inent obligations, then as a consequence you\nmay not distribute the Li"
  "brary at all.  For example, if a patent\nlicense would not permit royal"
  "ty-free redistribution of the Library by\nall those who receive copies "
  "directly or indirectly through you, then\nthe only way you could satisf"
  "y both it and this License would be to\nrefrain entirely from distribut"
  "ion of the Library.\n\nIf any portion of this section is held invalid o"
  "r unenforceable under any\nparticular circumstance, the balance of the "
  "section is intended to apply,\nand the section as a whole is intended t"
  "o apply in other circumstances.\n\nIt is not the purpose of this sectio"
  "n to induce you to infringe any\npatents or other property right claims"
  " or to contest validity of any\nsuch claims; this section has the sole "
  "purpose of protecting the\nintegrity of the free software distribution "
  "system which is\nimplemented by public license practices.  Many people "
  "have made\ngenerous contributions to the wide range of software distrib"
  "uted\nthrough that system in reliance on consistent application of that"
  "\nsystem; it is up to the author/donor to decide if he or she is willin"
  "g\nto distribute software through any other system and a licensee canno"
  "t\nimpose that choice.\n\nThis section is intended to make thoroughly c"
  "lear what is believed to\nbe a consequence of the rest of this License."
  "\n\n  12. If the distribution and/or use of the Library is restricted i"
  "n\ncertain countries either by patents or by copyrighted interfaces, th"
  "e\noriginal copyright holder who places the Library under this License "
  "may add\nan explicit geographical distribution limitation excluding tho"
  "se countries,\nso that distribution is permitted only in or among count"
  "ries not thus\nexcluded.  In such case, this License incorporates the l"
  "imitation as if\nwritten in the body of this License.\n\n  13. The Free"
  " Software Foundation may publish revised and/or new\nversions of the Li"
  "brary General Public License from time to time.\nSuch new versions will"
  " be similar in spirit to the present version,\nbut may differ in detail"
  " to address new problems or concerns.\n\nEach version is given a distin"
  "guishing version number.  If the Library\nspecifies a version number of"
  " this License which applies to it and\n\"any later version\", you have "
  "the option of following the terms and\nconditions either of that versio"
  "n or of any later version published by\nthe Free Software Foundation.  "
  "If the Library does not specify a\nlicense version number, you may choo"
  "se any version ever published by\nthe Free Software Foundation.\n\014\n"
  "  14. If you wish to incorporate parts of the Library into other free\n"
  "programs whose distribution conditions are incompatible with these,\nwr"
  "ite to the author to ask for permission.  For software which is\ncopyri"
  "ghted by the Free Software Foundation, write to the Free\nSoftware Foun"
  "dation; we sometimes make exceptions for this.  Our\ndecision will be g"
  "uided by the two goals of preserving the free status\nof all derivative"
  "s of our free software and of promoting the sharing\nand reuse of softw"
  "are generally.\n\n\t\t\t    NO WARRANTY\n\n  15. BECAUSE THE LIBRARY IS"
  " LICENSED FREE OF CHARGE, THERE IS NO\nWARRANTY FOR THE LIBRARY, TO THE"
  " EXTENT PERMITTED BY APPLICABLE LAW.\nEXCEPT WHEN OTHERWISE STATED IN W"
  "RITING THE COPYRIGHT HOLDERS AND/OR\nOTHER PARTIES PROVIDE THE LIBRARY "
  "\"AS IS\" WITHOUT WARRANTY OF ANY\nKIND, EITHER EXPRESSED OR IMPLIED, I"
  "NCLUDING, BUT NOT LIMITED TO, THE\nIMPLIED WARRANTIES OF MERCHANTABILIT"
  "Y AND FITNESS FOR A PARTICULAR\nPURPOSE.  THE ENTIRE RISK AS TO THE QUA"
  "LITY AND PERFORMANCE OF THE\nLIBRARY IS WITH YOU.  SHOULD THE LIBRARY P"
  "ROVE DEFECTIVE, YOU ASSUME\nTHE COST OF ALL NECESSARY SERVICING, REPAIR"
  " OR CORRECTION.\n\n  16. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW "
  "OR AGREED TO IN\nWRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY "
  "WHO MAY MODIFY\nAND/OR REDISTRIBUTE THE LIBRARY AS PERMITTED ABOVE, BE "
  "LIABLE TO YOU\nFOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL "
  "OR\nCONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE TH"
  "E\nLIBRARY (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING\nRE"
  "NDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A\nFAI"
  "LURE OF THE LIBRARY TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF\nSUCH "
  "HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH\nDAMA"
  "GES.\n\n\t\t     END OF TERMS AND CONDITIONS\n"
};

const unsigned data_txt_length = 23244u;

